@@ -2,12 +2,13 @@ from generalfile import Path
 from generallibrary import NetworkDiagram, Log, deco_cache
 
 from generalpackager.api.localrepo.base.localrepo_target import _SharedTarget
-from generalpackager.api.shared import _SharedAPI, _SharedName, _SharedPath
+from generalpackager.api.shared.files.shared_files import _Files
+from generalpackager.api.shared.path import _SharedPath
+from generalpackager.api.shared.name import _SharedName, _SharedAPI
 from generalpackager.other.packages import Packages
 from generalpackager.packager_api import _PackagerAPIs
 from generalpackager.packager_files import _PackagerFiles
 from generalpackager.packager_github import _PackagerGitHub
-from generalpackager.packager_markdown import _PackagerMarkdown
 from generalpackager.packager_metadata import _PackagerMetadata
 from generalpackager.packager_pypi import _PackagerPypi
 from generalpackager.packager_relations import _PackagerRelations
@@ -15,15 +16,15 @@ from generalpackager.packager_workflow import _PackagerWorkflow
 
 
 class Packager(NetworkDiagram,
-               _SharedAPI, _SharedName, _SharedTarget, _SharedPath,
-               _PackagerMarkdown, _PackagerGitHub, _PackagerFiles, _PackagerMetadata, _PackagerPypi, _PackagerWorkflow, _PackagerRelations, _PackagerAPIs):
+               _Files, _SharedAPI, _SharedName, _SharedTarget, _SharedPath,
+               _PackagerGitHub, _PackagerFiles, _PackagerMetadata, _PackagerPypi, _PackagerWorkflow, _PackagerRelations, _PackagerAPIs):
     """ Uses APIs to manage 'general' package.
         Contains methods that require more than one API as well as methods specific for ManderaGeneral. """
 
     author = 'Rickard "Mandera" Abraham'
     email = "rickard.abraham@gmail.com"
     license = "mit"
-    python = "3.8", "3.9", "3.10"  # Only supports basic definition with tuple of major.minor
+    python = "3.8", "3.9", "3.10", "3.11"  # Only supports basic definition with tuple of major.minor
     os = "windows", "ubuntu"  # , "macos"
 
     git_exclude_lines = npm_ignore_lines = ".idea/", "dist/", ".git/", "**test/tests/", ".coverage", "htmlcov/"
@@ -65,7 +66,7 @@ class Packager(NetworkDiagram,
             packagers = cls.packagers_from_packages()
 
             for packager in packagers:
-                Log(__name__).info(f"Downloading {packager.name} from GitHub.")
+                Log().info(f"Downloading {packager.name} from GitHub.")
                 packager.github.download()
 
     @staticmethod
